pub enum Spatula {
// some variants omitted
}Expand description
Convenient definition for every spatula in the game
Menu coordinates:
Spatula has support for interpeting a (usize, usize) value as a coordinate from the in-game menu,
where the first coordinate is the level-index and the second coordinate is the spatula-index,
and convert it to a Spatula value (or vice-versa).
use bfbb::Spatula;
let coord = (0,3);
let spatula = Spatula::try_from(coord).expect("'(0,3)' should be Spongebob's Closet");
assert_eq!(spatula, Spatula::SpongebobsCloset);
let closet = Spatula::SpongebobsCloset;
let coord: (usize, usize) = closet.into();
assert_eq!(coord, (0,3))Implementations
Sourceimpl Spatula
impl Spatula
Sourcepub fn get_offset(&self) -> Option<usize>
pub fn get_offset(&self) -> Option<usize>
In-game, spatula objects are stored within an array of entities.
get_offset gets the index of a spatula within that entity array.
NOTE: These indexes are only valid while the spatula’s level is loaded.
NOTE: This list is currently only validated for the Gamecube version of the game.